@@ -4,7 +4,7 @@
 # AdvancedWeb.pm
 # by John Heidemann
 # Copyright (C) 1996 by USC/ISI
-# $Id: AdvancedWeb.pm,v 1.4 1997/02/25 19:22:16 johnh Exp $
+# $Id: AdvancedWeb.pm,v 1.6 1997/11/04 01:04:13 johnh Exp $
 #
 # Complete copyright notice follows below.
 # 
@@ -14,7 +14,13 @@ package WWW::Search::AltaVista::AdvancedWeb;
 
 =head1 NAME
 
-WWW::Search::AltaVista::Web - class for advanced Alta Vista web searching
+WWW::Search::AltaVista::AdvancedWeb - class for advanced Alta Vista web searching
+
+
+=head1 SYNOPSIS
+    
+    require WWW::Search;
+    $search = new WWW::Search('AltaVista::AdvancedWeb');
 
 
 =head1 DESCRIPTION
@@ -74,6 +80,7 @@ sub native_setup_search
     if (!defined($self->{_options})) {
 	$self->{_options} = {
 	    pg => 'aq',
+	    'text' => 'yes',
 	    what => 'web',
 	    fmt => 'd',
 	    'search_url' => 'http://www.altavista.digital.com/cgi-bin/query',
