@@ -4,7 +4,7 @@
 # News.pm
 # by John Heidemann
 # Copyright (C) 1996 by USC/ISI
-# $Id: News.pm,v 1.4 1997/02/25 19:21:47 johnh Exp $
+# $Id: News.pm,v 1.6 1997/11/04 01:04:14 johnh Exp $
 #
 # Complete copyright notice follows below.
 # 
@@ -17,6 +17,12 @@ package WWW::Search::AltaVista::News;
 WWW::Search::AltaVista::News - class for Alta Vista news searching
 
 
+=head1 SYNOPSIS
+    
+    require WWW::Search;
+    $search = new WWW::Search('AltaVista::News');
+
+
 =head1 DESCRIPTION
 
 This class implements the AltaVista news search
@@ -74,6 +80,7 @@ sub native_setup_search
     if (!defined($self->{_options})) {
 	$self->{_options} = {
 	    pg => 'q',
+	    'text' => 'yes',
 	    what => 'news',
 	    fmt => 'd',
 	    'search_url' => 'http://www.altavista.digital.com/cgi-bin/query',
